# Relari CLI

```bash
relari-cli projects ls
relari-cli projects new PROJECT_NAME
relari-cli datasets ls PROJECT_ID 
relari-cli datasets new PROJECT_ID DATASET_PATH
relari-cli datasets get DATASET_ID OUT_DIR
relari-cli evaluations ls  PROJECT_ID
relari-cli evaluations get EVALUATION_ID OUT_DIR
```
